@@ -1,7 +1,7 @@
 """
 Type annotations for datasync service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/literals.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/literals/)
 
 Usage::
 
@@ -25,6 +25,9 @@ __all__ = (
     "EndpointTypeType",
     "FilterTypeType",
     "GidType",
+    "HdfsAuthenticationTypeType",
+    "HdfsDataTransferProtectionType",
+    "HdfsRpcProtectionType",
     "ListAgentsPaginatorName",
     "ListLocationsPaginatorName",
     "ListTagsForResourcePaginatorName",
@@ -51,8 +54,11 @@ __all__ = (
     "TransferModeType",
     "UidType",
     "VerifyModeType",
+    "DataSyncServiceName",
     "ServiceName",
+    "ResourceServiceName",
     "PaginatorName",
+    "RegionName",
 )
 
 
@@ -61,6 +67,9 @@ AtimeType = Literal["BEST_EFFORT", "NONE"]
 EndpointTypeType = Literal["FIPS", "PRIVATE_LINK", "PUBLIC"]
 FilterTypeType = Literal["SIMPLE_PATTERN"]
 GidType = Literal["BOTH", "INT_VALUE", "NAME", "NONE"]
+HdfsAuthenticationTypeType = Literal["KERBEROS", "SIMPLE"]
+HdfsDataTransferProtectionType = Literal["AUTHENTICATION", "DISABLED", "INTEGRITY", "PRIVACY"]
+HdfsRpcProtectionType = Literal["AUTHENTICATION", "DISABLED", "INTEGRITY", "PRIVACY"]
 ListAgentsPaginatorName = Literal["list_agents"]
 ListLocationsPaginatorName = Literal["list_locations"]
 ListTagsForResourcePaginatorName = Literal["list_tags_for_resource"]
@@ -108,6 +117,7 @@ TaskStatusType = Literal["AVAILABLE", "CREATING", "QUEUED", "RUNNING", "UNAVAILA
 TransferModeType = Literal["ALL", "CHANGED"]
 UidType = Literal["BOTH", "INT_VALUE", "NAME", "NONE"]
 VerifyModeType = Literal["NONE", "ONLY_FILES_TRANSFERRED", "POINT_IN_TIME_CONSISTENT"]
+DataSyncServiceName = Literal["datasync"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -141,6 +151,7 @@ ServiceName = Literal[
     "ce",
     "chime",
     "chime-sdk-identity",
+    "chime-sdk-meetings",
     "chime-sdk-messaging",
     "cloud9",
     "cloudcontrol",
@@ -395,6 +406,41 @@ ServiceName = Literal[
     "workspaces",
     "xray",
 ]
+ResourceServiceName = Literal[
+    "cloudformation",
+    "cloudwatch",
+    "dynamodb",
+    "ec2",
+    "glacier",
+    "iam",
+    "opsworks",
+    "s3",
+    "sns",
+    "sqs",
+]
 PaginatorName = Literal[
     "list_agents", "list_locations", "list_tags_for_resource", "list_task_executions", "list_tasks"
 ]
+RegionName = Literal[
+    "af-south-1",
+    "ap-east-1",
+    "ap-northeast-1",
+    "ap-northeast-2",
+    "ap-northeast-3",
+    "ap-south-1",
+    "ap-southeast-1",
+    "ap-southeast-2",
+    "ca-central-1",
+    "eu-central-1",
+    "eu-north-1",
+    "eu-south-1",
+    "eu-west-1",
+    "eu-west-2",
+    "eu-west-3",
+    "me-south-1",
+    "sa-east-1",
+    "us-east-1",
+    "us-east-2",
+    "us-west-1",
+    "us-west-2",
+]
