@@ -1,7 +1,7 @@
 """
 Type annotations for datasync service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/type_defs.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/type_defs/)
 
 Usage::
 
@@ -13,13 +13,19 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Any, Dict, List, Sequence
+from typing import IO, Dict, List, Sequence, Union
+
+from botocore.response import StreamingBody
+from typing_extensions import NotRequired
 
 from .literals import (
     AgentStatusType,
     AtimeType,
     EndpointTypeType,
     GidType,
+    HdfsAuthenticationTypeType,
+    HdfsDataTransferProtectionType,
+    HdfsRpcProtectionType,
     LocationFilterNameType,
     LogLevelType,
     MtimeType,
@@ -62,6 +68,8 @@ __all__ = (
     "CreateLocationEfsResponseTypeDef",
     "CreateLocationFsxWindowsRequestRequestTypeDef",
     "CreateLocationFsxWindowsResponseTypeDef",
+    "CreateLocationHdfsRequestRequestTypeDef",
+    "CreateLocationHdfsResponseTypeDef",
     "CreateLocationNfsRequestRequestTypeDef",
     "CreateLocationNfsResponseTypeDef",
     "CreateLocationObjectStorageRequestRequestTypeDef",
@@ -81,6 +89,8 @@ __all__ = (
     "DescribeLocationEfsResponseTypeDef",
     "DescribeLocationFsxWindowsRequestRequestTypeDef",
     "DescribeLocationFsxWindowsResponseTypeDef",
+    "DescribeLocationHdfsRequestRequestTypeDef",
+    "DescribeLocationHdfsResponseTypeDef",
     "DescribeLocationNfsRequestRequestTypeDef",
     "DescribeLocationNfsResponseTypeDef",
     "DescribeLocationObjectStorageRequestRequestTypeDef",
@@ -95,14 +105,20 @@ __all__ = (
     "DescribeTaskResponseTypeDef",
     "Ec2ConfigTypeDef",
     "FilterRuleTypeDef",
+    "HdfsNameNodeTypeDef",
+    "ListAgentsRequestListAgentsPaginateTypeDef",
     "ListAgentsRequestRequestTypeDef",
     "ListAgentsResponseTypeDef",
+    "ListLocationsRequestListLocationsPaginateTypeDef",
     "ListLocationsRequestRequestTypeDef",
     "ListLocationsResponseTypeDef",
+    "ListTagsForResourceRequestListTagsForResourcePaginateTypeDef",
     "ListTagsForResourceRequestRequestTypeDef",
     "ListTagsForResourceResponseTypeDef",
+    "ListTaskExecutionsRequestListTaskExecutionsPaginateTypeDef",
     "ListTaskExecutionsRequestRequestTypeDef",
     "ListTaskExecutionsResponseTypeDef",
+    "ListTasksRequestListTasksPaginateTypeDef",
     "ListTasksRequestRequestTypeDef",
     "ListTasksResponseTypeDef",
     "LocationFilterTypeDef",
@@ -112,6 +128,7 @@ __all__ = (
     "OptionsTypeDef",
     "PaginatorConfigTypeDef",
     "PrivateLinkConfigTypeDef",
+    "QopConfigurationTypeDef",
     "ResponseMetadataTypeDef",
     "S3ConfigTypeDef",
     "SmbMountOptionsTypeDef",
@@ -126,6 +143,7 @@ __all__ = (
     "TaskScheduleTypeDef",
     "UntagResourceRequestRequestTypeDef",
     "UpdateAgentRequestRequestTypeDef",
+    "UpdateLocationHdfsRequestRequestTypeDef",
     "UpdateLocationNfsRequestRequestTypeDef",
     "UpdateLocationObjectStorageRequestRequestTypeDef",
     "UpdateLocationSmbRequestRequestTypeDef",
@@ -249,6 +267,47 @@ CreateLocationFsxWindowsResponseTypeDef = TypedDict(
     },
 )
 
+_RequiredCreateLocationHdfsRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateLocationHdfsRequestRequestTypeDef",
+    {
+        "NameNodes": Sequence["HdfsNameNodeTypeDef"],
+        "AuthenticationType": HdfsAuthenticationTypeType,
+        "AgentArns": Sequence[str],
+    },
+)
+_OptionalCreateLocationHdfsRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateLocationHdfsRequestRequestTypeDef",
+    {
+        "Subdirectory": str,
+        "BlockSize": int,
+        "ReplicationFactor": int,
+        "KmsKeyProviderUri": str,
+        "QopConfiguration": "QopConfigurationTypeDef",
+        "SimpleUser": str,
+        "KerberosPrincipal": str,
+        "KerberosKeytab": Union[bytes, IO[bytes], StreamingBody],
+        "KerberosKrb5Conf": Union[bytes, IO[bytes], StreamingBody],
+        "Tags": Sequence["TagListEntryTypeDef"],
+    },
+    total=False,
+)
+
+
+class CreateLocationHdfsRequestRequestTypeDef(
+    _RequiredCreateLocationHdfsRequestRequestTypeDef,
+    _OptionalCreateLocationHdfsRequestRequestTypeDef,
+):
+    pass
+
+
+CreateLocationHdfsResponseTypeDef = TypedDict(
+    "CreateLocationHdfsResponseTypeDef",
+    {
+        "LocationArn": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 _RequiredCreateLocationNfsRequestRequestTypeDef = TypedDict(
     "_RequiredCreateLocationNfsRequestRequestTypeDef",
     {
@@ -502,6 +561,32 @@ DescribeLocationFsxWindowsResponseTypeDef = TypedDict(
     },
 )
 
+DescribeLocationHdfsRequestRequestTypeDef = TypedDict(
+    "DescribeLocationHdfsRequestRequestTypeDef",
+    {
+        "LocationArn": str,
+    },
+)
+
+DescribeLocationHdfsResponseTypeDef = TypedDict(
+    "DescribeLocationHdfsResponseTypeDef",
+    {
+        "LocationArn": str,
+        "LocationUri": str,
+        "NameNodes": List["HdfsNameNodeTypeDef"],
+        "BlockSize": int,
+        "ReplicationFactor": int,
+        "KmsKeyProviderUri": str,
+        "QopConfiguration": "QopConfigurationTypeDef",
+        "AuthenticationType": HdfsAuthenticationTypeType,
+        "SimpleUser": str,
+        "KerberosPrincipal": str,
+        "AgentArns": List[str],
+        "CreationTime": datetime,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 DescribeLocationNfsRequestRequestTypeDef = TypedDict(
     "DescribeLocationNfsRequestRequestTypeDef",
     {
@@ -656,6 +741,22 @@ FilterRuleTypeDef = TypedDict(
     total=False,
 )
 
+HdfsNameNodeTypeDef = TypedDict(
+    "HdfsNameNodeTypeDef",
+    {
+        "Hostname": str,
+        "Port": int,
+    },
+)
+
+ListAgentsRequestListAgentsPaginateTypeDef = TypedDict(
+    "ListAgentsRequestListAgentsPaginateTypeDef",
+    {
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
 ListAgentsRequestRequestTypeDef = TypedDict(
     "ListAgentsRequestRequestTypeDef",
     {
@@ -674,6 +775,15 @@ ListAgentsResponseTypeDef = TypedDict(
     },
 )
 
+ListLocationsRequestListLocationsPaginateTypeDef = TypedDict(
+    "ListLocationsRequestListLocationsPaginateTypeDef",
+    {
+        "Filters": Sequence["LocationFilterTypeDef"],
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
 ListLocationsRequestRequestTypeDef = TypedDict(
     "ListLocationsRequestRequestTypeDef",
     {
@@ -693,6 +803,28 @@ ListLocationsResponseTypeDef = TypedDict(
     },
 )
 
+_RequiredListTagsForResourceRequestListTagsForResourcePaginateTypeDef = TypedDict(
+    "_RequiredListTagsForResourceRequestListTagsForResourcePaginateTypeDef",
+    {
+        "ResourceArn": str,
+    },
+)
+_OptionalListTagsForResourceRequestListTagsForResourcePaginateTypeDef = TypedDict(
+    "_OptionalListTagsForResourceRequestListTagsForResourcePaginateTypeDef",
+    {
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
+
+class ListTagsForResourceRequestListTagsForResourcePaginateTypeDef(
+    _RequiredListTagsForResourceRequestListTagsForResourcePaginateTypeDef,
+    _OptionalListTagsForResourceRequestListTagsForResourcePaginateTypeDef,
+):
+    pass
+
+
 _RequiredListTagsForResourceRequestRequestTypeDef = TypedDict(
     "_RequiredListTagsForResourceRequestRequestTypeDef",
     {
@@ -725,6 +857,15 @@ ListTagsForResourceResponseTypeDef = TypedDict(
     },
 )
 
+ListTaskExecutionsRequestListTaskExecutionsPaginateTypeDef = TypedDict(
+    "ListTaskExecutionsRequestListTaskExecutionsPaginateTypeDef",
+    {
+        "TaskArn": str,
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
 ListTaskExecutionsRequestRequestTypeDef = TypedDict(
     "ListTaskExecutionsRequestRequestTypeDef",
     {
@@ -744,6 +885,15 @@ ListTaskExecutionsResponseTypeDef = TypedDict(
     },
 )
 
+ListTasksRequestListTasksPaginateTypeDef = TypedDict(
+    "ListTasksRequestListTasksPaginateTypeDef",
+    {
+        "Filters": Sequence["TaskFilterTypeDef"],
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
 ListTasksRequestRequestTypeDef = TypedDict(
     "ListTasksRequestRequestTypeDef",
     {
@@ -838,13 +988,22 @@ PrivateLinkConfigTypeDef = TypedDict(
     total=False,
 )
 
+QopConfigurationTypeDef = TypedDict(
+    "QopConfigurationTypeDef",
+    {
+        "RpcProtection": HdfsRpcProtectionType,
+        "DataTransferProtection": HdfsDataTransferProtectionType,
+    },
+    total=False,
+)
+
 ResponseMetadataTypeDef = TypedDict(
     "ResponseMetadataTypeDef",
     {
         "RequestId": str,
         "HostId": str,
         "HTTPStatusCode": int,
-        "HTTPHeaders": Dict[str, Any],
+        "HTTPHeaders": Dict[str, str],
         "RetryAttempts": int,
     },
 )
@@ -1003,6 +1162,39 @@ class UpdateAgentRequestRequestTypeDef(
     pass
 
 
+_RequiredUpdateLocationHdfsRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateLocationHdfsRequestRequestTypeDef",
+    {
+        "LocationArn": str,
+    },
+)
+_OptionalUpdateLocationHdfsRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateLocationHdfsRequestRequestTypeDef",
+    {
+        "Subdirectory": str,
+        "NameNodes": Sequence["HdfsNameNodeTypeDef"],
+        "BlockSize": int,
+        "ReplicationFactor": int,
+        "KmsKeyProviderUri": str,
+        "QopConfiguration": "QopConfigurationTypeDef",
+        "AuthenticationType": HdfsAuthenticationTypeType,
+        "SimpleUser": str,
+        "KerberosPrincipal": str,
+        "KerberosKeytab": Union[bytes, IO[bytes], StreamingBody],
+        "KerberosKrb5Conf": Union[bytes, IO[bytes], StreamingBody],
+        "AgentArns": Sequence[str],
+    },
+    total=False,
+)
+
+
+class UpdateLocationHdfsRequestRequestTypeDef(
+    _RequiredUpdateLocationHdfsRequestRequestTypeDef,
+    _OptionalUpdateLocationHdfsRequestRequestTypeDef,
+):
+    pass
+
+
 _RequiredUpdateLocationNfsRequestRequestTypeDef = TypedDict(
     "_RequiredUpdateLocationNfsRequestRequestTypeDef",
     {
